summaryrefslogtreecommitdiffstats
path: root/test/integration/api_test
diff options
context:
space:
mode:
authorJean-Philippe Lang <jp_lang@yahoo.fr>2014-12-21 12:39:48 +0000
committerJean-Philippe Lang <jp_lang@yahoo.fr>2014-12-21 12:39:48 +0000
commit2a6692248b8976141997c4418561bb0800baf2da (patch)
tree68c7fe2afb20e1daa1790cdc3e61a06a53768ba9 /test/integration/api_test
parente2998505b2403a70c233cf96fac8432e950bf47d (diff)
downloadredmine-2a6692248b8976141997c4418561bb0800baf2da.tar.gz
redmine-2a6692248b8976141997c4418561bb0800baf2da.zip
Replaced "can't" with "cannot" in error messages.
git-svn-id: http://svn.redmine.org/redmine/trunk@13781 e93f8b46-1217-0410-a6f0-8f06a7374b81
Diffstat (limited to 'test/integration/api_test')
-rw-r--r--test/integration/api_test/groups_test.rb4
-rw-r--r--test/integration/api_test/issue_categories_test.rb4
-rw-r--r--test/integration/api_test/issues_test.rb10
-rw-r--r--test/integration/api_test/memberships_test.rb6
-rw-r--r--test/integration/api_test/projects_test.rb4
-rw-r--r--test/integration/api_test/time_entries_test.rb4
-rw-r--r--test/integration/api_test/users_test.rb4
-rw-r--r--test/integration/api_test/versions_test.rb2
8 files changed, 19 insertions, 19 deletions
diff --git a/test/integration/api_test/groups_test.rb b/test/integration/api_test/groups_test.rb
index 1efeaaa21..2fe8271b1 100644
--- a/test/integration/api_test/groups_test.rb
+++ b/test/integration/api_test/groups_test.rb
@@ -144,7 +144,7 @@ class Redmine::ApiTest::GroupsTest < Redmine::ApiTest::Base
assert_equal 'application/xml', response.content_type
assert_select 'errors' do
- assert_select 'error', :text => /Name can't be blank/
+ assert_select 'error', :text => /Name cannot be blank/
end
end
@@ -164,7 +164,7 @@ class Redmine::ApiTest::GroupsTest < Redmine::ApiTest::Base
assert_equal 'application/xml', response.content_type
assert_select 'errors' do
- assert_select 'error', :text => /Name can't be blank/
+ assert_select 'error', :text => /Name cannot be blank/
end
end
diff --git a/test/integration/api_test/issue_categories_test.rb b/test/integration/api_test/issue_categories_test.rb
index c83b32961..9af14cd1a 100644
--- a/test/integration/api_test/issue_categories_test.rb
+++ b/test/integration/api_test/issue_categories_test.rb
@@ -57,7 +57,7 @@ class Redmine::ApiTest::IssueCategoriesTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Name can't be blank"
+ assert_select 'errors error', :text => "Name cannot be blank"
end
test "PUT /issue_categories/:id.xml with valid parameters should update the issue category" do
@@ -76,7 +76,7 @@ class Redmine::ApiTest::IssueCategoriesTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Name can't be blank"
+ assert_select 'errors error', :text => "Name cannot be blank"
end
test "DELETE /issue_categories/:id.xml should destroy the issue category" do
diff --git a/test/integration/api_test/issues_test.rb b/test/integration/api_test/issues_test.rb
index ba8dbc6b2..161beee67 100644
--- a/test/integration/api_test/issues_test.rb
+++ b/test/integration/api_test/issues_test.rb
@@ -90,7 +90,7 @@ class Redmine::ApiTest::IssuesTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Start date can't be blank"
+ assert_select 'errors error', :text => "Start date cannot be blank"
end
test "GET /issues.xml with custom field filter" do
@@ -361,7 +361,7 @@ class Redmine::ApiTest::IssuesTest < Redmine::ApiTest::Base
post '/issues.xml', {:issue => {:project_id => 1}}, credentials('jsmith')
end
- assert_select 'errors error', :text => "Subject can't be blank"
+ assert_select 'errors error', :text => "Subject cannot be blank"
end
test "POST /issues.json should create an issue with the attributes" do
@@ -385,7 +385,7 @@ class Redmine::ApiTest::IssuesTest < Redmine::ApiTest::Base
end
json = ActiveSupport::JSON.decode(response.body)
- assert json['errors'].include?("Subject can't be blank")
+ assert json['errors'].include?("Subject cannot be blank")
end
test "PUT /issues/:id.xml" do
@@ -444,7 +444,7 @@ class Redmine::ApiTest::IssuesTest < Redmine::ApiTest::Base
put '/issues/6.xml', {:issue => {:subject => ''}}, credentials('jsmith')
assert_response :unprocessable_entity
- assert_select 'errors error', :text => "Subject can't be blank"
+ assert_select 'errors error', :text => "Subject cannot be blank"
end
test "PUT /issues/:id.json" do
@@ -468,7 +468,7 @@ class Redmine::ApiTest::IssuesTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
json = ActiveSupport::JSON.decode(response.body)
- assert json['errors'].include?("Subject can't be blank")
+ assert json['errors'].include?("Subject cannot be blank")
end
test "DELETE /issues/:id.xml" do
diff --git a/test/integration/api_test/projects_test.rb b/test/integration/api_test/projects_test.rb
index dd25d2101..2bc4da278 100644
--- a/test/integration/api_test/projects_test.rb
+++ b/test/integration/api_test/projects_test.rb
@@ -179,7 +179,7 @@ class Redmine::ApiTest::ProjectsTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Identifier can't be blank"
+ assert_select 'errors error', :text => "Identifier cannot be blank"
end
test "PUT /projects/:id.xml with valid parameters should update the project" do
@@ -220,7 +220,7 @@ class Redmine::ApiTest::ProjectsTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Name can't be blank"
+ assert_select 'errors error', :text => "Name cannot be blank"
end
test "DELETE /projects/:id.xml should delete the project" do
diff --git a/test/integration/api_test/time_entries_test.rb b/test/integration/api_test/time_entries_test.rb
index b118ed72f..492ecad0b 100644
--- a/test/integration/api_test/time_entries_test.rb
+++ b/test/integration/api_test/time_entries_test.rb
@@ -102,7 +102,7 @@ class Redmine::ApiTest::TimeEntriesTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Hours can't be blank"
+ assert_select 'errors error', :text => "Hours cannot be blank"
end
test "PUT /time_entries/:id.xml with valid parameters should update time entry" do
@@ -121,7 +121,7 @@ class Redmine::ApiTest::TimeEntriesTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Hours can't be blank"
+ assert_select 'errors error', :text => "Hours cannot be blank"
end
test "DELETE /time_entries/:id.xml should destroy time entry" do
diff --git a/test/integration/api_test/users_test.rb b/test/integration/api_test/users_test.rb
index beadc54c6..b0b0f6258 100644
--- a/test/integration/api_test/users_test.rb
+++ b/test/integration/api_test/users_test.rb
@@ -183,7 +183,7 @@ class Redmine::ApiTest::UsersTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "First name can't be blank"
+ assert_select 'errors error', :text => "First name cannot be blank"
end
test "POST /users.json with with invalid parameters should return errors" do
@@ -253,7 +253,7 @@ class Redmine::ApiTest::UsersTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "First name can't be blank"
+ assert_select 'errors error', :text => "First name cannot be blank"
end
test "PUT /users/:id.json with invalid parameters" do
diff --git a/test/integration/api_test/versions_test.rb b/test/integration/api_test/versions_test.rb
index a53c29b07..2b04236d4 100644
--- a/test/integration/api_test/versions_test.rb
+++ b/test/integration/api_test/versions_test.rb
@@ -94,7 +94,7 @@ class Redmine::ApiTest::VersionsTest < Redmine::ApiTest::Base
end
assert_response :unprocessable_entity
- assert_select 'errors error', :text => "Name can't be blank"
+ assert_select 'errors error', :text => "Name cannot be blank"
end
test "GET /versions/:id.xml should return the version" do
diff --git a/test/integration/api_test/memberships_test.rb b/test/integration/api_test/memberships_test.rb
index aecd90aca..9313cf759 100644
--- a/test/integration/api_test/memberships_test.rb
+++ b/test/integration/api_test/memberships_test.rb
@@ -85,7 +85,7 @@ class Redmine::ApiTest::MembershipsTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Principal can't be blank"
+ assert_select 'errors error', :text => "Principal cannot be blank"
end
end
@@ -133,7 +133,7 @@ class Redmine::ApiTest::MembershipsTest < Redmine::ApiTest::Base
assert_response :unprocessable_entity
assert_equal 'application/xml', @response.content_type
- assert_select 'errors error', :text => "Role can't be empty"
+ assert_select 'errors error', :text => "Role cannot be empty"
end
test "DELETE /memberships/:id.xml should destroy the membership" do
@@ -148,7 +148,7 @@ class Redmine::ApiTest::MembershipsTest < Redmine::ApiTest::Base
test "DELETE /memberships/:id.xml should respond with 422 on failure" do
assert_no_difference 'Member.count' do
# A membership with an inherited role can't be deleted
Member.find(2).member_roles.first.update_attribute :inherited_from, 99
delete '/memberships/2.xml', {}, credentials('jsmith')
@@ -148,7 +148,7 @@ class Redmine::ApiTest::MembershipsTest < Redmine::ApiTest::Base
test "DELETE /memberships/:id.xml should respond with 422 on failure" do
assert_no_difference 'Member.count' do
- # A membership with an inherited role can't be deleted
+ # A membership with an inherited role cannot be deleted
Member.find(2).member_roles.first.update_attribute :inherited_from, 99
delete '/memberships/2.xml', {}, credentials('jsmith')